@@ -4,11 +4,16 @@ from cast_arg.actionPlan import ActionPlan
 from cast_arg.config import Config
 from cast_arg.pages.greenIt import GreenIt
 from cast_arg.pages.summary import HighlightSummary
-
 from cast_arg.stats import OssStats,AIPStats,LicenseStats
+
+from cast_arg.pages.tech_detail_table import TechDetailTable
+
+
+from cast_common.mri import MRI
 from cast_common.logger import Logger,DEBUG, INFO, WARN
 from cast_common.util import find_nth, no_dups, list_to_text,format_table
 from cast_arg.powerpoint import PowerPoint
+from cast_common.highlight import Highlight
 
 
 from pandas import DataFrame
@@ -43,6 +48,8 @@ class GeneratePPT(Logger):
     _hl_apps_df = pd.DataFrame()
     _hl_app_list = []
 
+    day_rate=1600
+
     def __init__(self, config:Config):
         super().__init__("generate",config.logging_generate)
         self._config = config
@@ -57,13 +64,19 @@ class GeneratePPT(Logger):
         if config.aip_active:
             self.info("Collecting AIP Data")
             self._aip_data = AipData(config,log_level=config.logging_aip)
+
+            self.mri_pages = [
+                TechDetailTable()
+
+            ]
+
         if config.hl_active:
             self.info("Collecting Highlight Data")
+            hl = Highlight(hl_base_url=config.hl_url,hl_user=config.hl_user,hl_pswd=config.hl_password, \
+                           hl_instance=config.hl_instance,hl_apps=config.hl_list)
             self.hl_pages = [
-                HighlightSummary(hl_user=config.hl_user,hl_pswd=config.hl_password,hl_instance=config.hl_instance,
-                        hl_base_url=config.hl_url,log_level=config.logging_highlight),
-                GreenIt(hl_user=config.hl_user,hl_pswd=config.hl_password,hl_instance=config.hl_instance,
-                        hl_base_url=config.hl_url,log_level=config.logging_highlight)
+                HighlightSummary(self.day_rate),
+                GreenIt(self._config.output)
             ]
             self._hl_data = HLData(config,log_level=config.logging_highlight)
 
@@ -128,7 +141,7 @@ class GeneratePPT(Logger):
         app_list = self._config.aip_list
         hl_list = self._config.hl_list
 
-        day_rate = 1600
+        day_rate = self.day_rate
 
         summary_near_term=AIPStats(day_rate,logger_level=self._config.logging_generate)
         summary_fix_now=AIPStats(day_rate,logger_level=self._config.logging_generate)
@@ -139,6 +152,7 @@ class GeneratePPT(Logger):
         lic_summary = LicenseStats(logger_level=self._config.logging_generate)
         summary_components = 0
 
+        self._ppt.replace_text('{app_cnt}',app_cnt)
         for idx in range(0,app_cnt):
             # create instance of action plan class 
             self.ap = ActionPlan (app_list,self._aip_data,self._ppt,self._config.output,day_rate)
@@ -157,9 +171,13 @@ class GeneratePPT(Logger):
             self.info(f'********************* Working on pages for {app_title} ******************************')
             self._ppt.replace_text(f'{{app{app_no}_name}}',app_title)
 
+            if self._config.aip_active:
+                for proc in self.mri_pages:
+                    proc.report(app_id,app_no)
+
             if self._config.hl_active:
                 for proc in self.hl_pages:
-                    proc.report(hl_id,app_no,self._ppt,self._config.output)
+                    proc.report(hl_id,app_no)
 
             if self._config.aip_active:
                 if self._aip_data.has_data(app_id):
@@ -178,8 +196,8 @@ class GeneratePPT(Logger):
                     grade_all = self._aip_data.get_app_grades(app_id)
                     #self._ppt.replace_risk_factor(grade_all,app_no)
                     grade_by_tech_df = self._aip_data.get_grade_by_tech(app_id)
-                    grades = grade_by_tech_df.drop(['Documentation',"ISO","ISO_EFF","ISO_MAINT","ISO_REL","ISO_SEC"],axis=1)
-                    self._ppt.update_table(f'app{app_no}_grade_by_tech_table',grades)
+                    # grades = grade_by_tech_df.drop(['Documentation',"ISO","ISO_EFF","ISO_MAINT","ISO_REL","ISO_SEC"],axis=1)
+                    # self._ppt.update_table(f'app{app_no}_grade_by_tech_table',grades)
 
                     if not grade_by_tech_df.empty:
                         #add appmarq technology
@@ -248,7 +266,7 @@ class GeneratePPT(Logger):
                         self._ppt.replace_text(f'{{app{app_no}_comment_out_pct}}',percent_comment_out)
 
                         loc_tbl['percent']=pd.Series(["{0:.2f}%".format(val) for val in loc_tbl['percent']], index = loc_tbl.index)
-                        self._ppt.update_table(f'app{app_no}_loc_table',loc_tbl,has_header=False)
+                        self._ppt.update_table(f'app{app_no}_loc_table',loc_tbl,header_rows=0)
                         self._ppt.update_chart(f'app{app_no}_loc_pie_chart',DataFrame(loc_tbl['loc']))
 
                         # self._ppt.replace_grade(grade_all,app_no)
@@ -334,6 +352,8 @@ class GeneratePPT(Logger):
                     lic_summary.add_high(lic.high)
                     lic_summary.add_medium(lic.medium)
                     lic_summary.add_low(lic.low)
+
+
                 except KeyError as ex:
                     self.warning(f'OSS information not found {str(ex)}')
                 """
@@ -537,13 +557,13 @@ class GeneratePPT(Logger):
     def fill_critical_rules(self,app_id,app_no):
         self.info('Filling critical rules table')
         rules_df = self._aip_data.critical_rules(app_id)
-
-#        crit_rule_cols = [col for col in rules_df if col.startswith('rulePattern')]
-        rules_df = rules_df[['rulePattern.name','rulePattern.critical']]
-        rule_summary_df=rules_df.groupby(['rulePattern.name']).size().reset_index(name='counts').sort_values(by=['counts'],ascending=False)
-        rule_summary_df=rule_summary_df.head(5)
-        self._ppt.update_table(f'app{app_no}_top_violations',rule_summary_df,include_index=False)
-
+        if not rules_df.empty:
+            rules_df = rules_df[['rulePattern.name','rulePattern.critical']]
+            rule_summary_df=rules_df.groupby(['rulePattern.name']).size().reset_index(name='counts').sort_values(by=['counts'],ascending=False)
+            rule_summary_df=rule_summary_df.head(5)
+            self._ppt.update_table(f'app{app_no}_top_violations',rule_summary_df,include_index=False)
+        else:
+            self.warning('This application contains no critical violations')
         # if not rules_df.empty:
         #     critical_rule_df = pd.json_normalize(rules_df['rulePattern'])
         #     critical_rule_df = critical_rule_df[['name','critical']]
@@ -610,7 +630,7 @@ class GeneratePPT(Logger):
 
         self._ppt.replace_text(f'{{app{app_no}_oss_cmpn_tot}}',total_components)
         if not oss_df.empty:
-            self._ppt.update_table(f'app{app_no}_HL_table_CVEs',oss_df,include_index=False,max_rows=5)
+            self._ppt.update_table(f'app{app_no}_HL_table_CVEs',oss_df,include_index=False)
 
         self.info('Filling OSS license table')
         '''
@@ -645,10 +665,7 @@ class GeneratePPT(Logger):
                 lic_summary.loc[lic_summary['risk']=='Medium','forground']='127,127,127'
 
                 #update the powerpoint table
-                self._ppt.update_table(f'app{app_no}_HL_table_lic_risks',
-                                    lic_summary,include_index=False,
-                                    forground='forground',
-                                    max_rows=3)
+                self._ppt.update_table(f'app{app_no}_HL_table_lic_risks',lic_summary,include_index=False)
             
                 lic.high = lic_summary[lic_summary['risk']=='High']['comp count'].sum()
                 lic.medium = lic_summary[lic_summary['risk']=='Medium']['comp count'].sum()
