@@ -9,9 +9,9 @@ __email__ = "n.kaplan@castsoftware.com"
 __copyright__ = "Copyright 2023, CAST Software"
 
 if __name__ == '__main__':
-    print('\nCAST Assessment Deck Generation Tool')
+    print('\nCAST Assessment Deck Generation Tool (ARG)')
     print('Copyright (c) 2023 CAST Software Inc.\n')
-    print('If you need assistance, please contact Nevin Kaplan (NKA) from the CAST US PS team\n')
+    print('If you need assistance, please contact oneclick@castsoftware.com\n')
 
     parser = ArgumentParser(description='Assessment Report Generation Tool')
     parser.add_argument('-c','--config', required=True, help='Configuration properties file')
