@@ -10,6 +10,7 @@ from cast_common.logger import Logger,DEBUG, INFO, ERROR
 from cast_common.restAPI import RestCall
 from cast_common.aipRestCall import AipRestCall
 from cast_common.hlRestCall import HLRestCall
+from cast_common.powerpoint import PowerPoint
 
 import enum
 import urllib.parse
@@ -53,8 +54,9 @@ class AipData(AipRestCall):
 
     _health_grade_ids = ['Efficiency','Robustness','Security','Changeability','Transferability']
 
-    def __init__(self, config, timer_on=False,log_level=INFO):
-        super().__init__(base_url=config.aip_url, user=config.aip_user, password=config.aip_password, track_time=timer_on,log_level=log_level)
+    def __init__(self, config,output:str=None,timer_on=False,log_level=INFO):
+        super().__init__(base_url=config.aip_url, user=config.aip_user, pswd=config.aip_password, 
+                         track_time=timer_on,log_level=log_level)
 
         #self._rest=rest
         #self._base=app_list
@@ -75,6 +77,11 @@ class AipData(AipRestCall):
                     self.info('AIP is active')
                     self._data[s]['has data'] = True
 
+                    self.info('action plan data')
+                    (ap_df,ap_summary_df) = self.get_action_plan(domain_id,self._data[s]['snapshot']['id']) 
+                    self._data[s]['action_plan']=ap_df
+                    self._data[s]['action_plan_summary']=ap_summary_df
+
                     self.info('TQI compliance data')
                     self._data[s]['tqi_compliance']=self.aggregate_violation_ratio(domain_id,snapshot['id'],'60017',self._imp_list)
 
@@ -107,10 +114,6 @@ class AipData(AipRestCall):
 
 
 
-                    self.info('action plan data')
-                    (ap_df,ap_summary_df) = self.get_action_plan(domain_id,self._data[s]['snapshot']['id']) 
-                    self._data[s]['action_plan']=ap_df
-                    self._data[s]['action_plan_summary']=ap_summary_df
                     self.info('AIP data retrieval complete')
             else:
                 self.logger.warn(f'Domain not found for {s}')
